Uchcharaka is designed to transcribe non-Indian languages into Indian scripts while closely preserving their native pronunciations. It offers three levels of transcription, ranging from low to high fidelity. The high-fidelity level retains as many non-Indic phonemes as possible, while the low-fidelity level captures only the essential phonetic elements. Currently, the tool supports English (US and UK), Spanish (Spain and Latin America), Portuguese (Brazil and Portual), Italian, German, and French.

Uchcharaka requires espeak-ng to be installed and available in the system path. Please install eSpeak NG (https://github.com/espeak-ng/espeak-ng) in your system before installing Uchcharaka.

You can read the usage instructions here (https://uchcharaka.aksharamukha.com/python).

The web interface is here: https://uchcharaka.aksharamukha.com